/*
*********************************************************************************************************
*                                         BOARD SUPPORT PACKAGE
*
*                            (c) Copyright 2010; Micrium, Inc.; Weston, FL
*
*               All rights reserved. Protected by international copyright laws.
*
*               BSP is provided in source form to registered licensees ONLY.  It is
*               illegal to distribute this source code to any third party unless you receive
*               written permission by an authorized Micrium representative.  Knowledge of
*               the source code may NOT be used to develop a similar product.
*
*               Please help us continue to provide the Embedded community with the finest
*               software available.  Your honesty is greatly appreciated.
*
*               You can contact us at www.micrium.com.
*********************************************************************************************************
*/

/*
*********************************************************************************************************
*
*                                         BOARD SUPPORT PACKAGE
*
*                                              Renesas RX62N
*                                                on the
*                                      RSK-2+RX62N Evaluation Board
*
* Filename      : bsp_glcd.c
* Version       : V1.00
* Programmer(s) : FGK
*********************************************************************************************************
*/

#include  <includes.h>
#include  <bsp_glcd.h>
#include  "iodefine.h"

/*
*********************************************************************************************************
*                                          GLOBAL VARIABLES
*********************************************************************************************************
*/

static  T_glyphHandle  BSP_GraphLCD;

/*
*********************************************************************************************************
*                                      GRAPH LCD INITIALIZATION
*********************************************************************************************************
*/

void  BSP_GraphLCD_Init (void)
{
    T_glyphError  err;


    err = GlyphOpen(&BSP_GraphLCD, 0);

    if (err == GLYPH_ERROR_NONE) {
        GlyphNormalScreen(BSP_GraphLCD);
        GlyphClearScreen(BSP_GraphLCD);
    }
}


/*
*********************************************************************************************************
*                                       GRAPH LCD CLEAR SCREEN
*********************************************************************************************************
*/

void  BSP_GraphLCD_Clear (void)
{
    GlyphClearScreen(BSP_GraphLCD);
}


/*
*********************************************************************************************************
*                                         GRAPH LCD SET FONT
*********************************************************************************************************
*/

void  BSP_GraphLCD_SetFont (CPU_INT08U  font)
{
    switch (font) {
        case BSP_GLCD_FONT_LARGE:
             GlyphSetFont(BSP_GraphLCD, GLYPH_FONT_8_BY_8);
             break;

        case BSP_GLCD_FONT_SMALL:
             GlyphSetFont(BSP_GraphLCD, GLYPH_FONT_5_BY_7);
             break;
    }
}


/*
*********************************************************************************************************
*                                       GRAPH LCD PRINT STRING
*********************************************************************************************************
*/

void  BSP_GraphLCD_String (CPU_INT08U   line,
                           CPU_CHAR    *p_str)
{
    CPU_INT08U  y;


    y = line * 9u;

    GlyphEraseBlock(BSP_GraphLCD, 0u, y, 95u, y + 8u);
    GlyphSetXY     (BSP_GraphLCD, 0u, y);
    GlyphString    (BSP_GraphLCD, (uint8_t *)p_str, Str_Len(p_str));
}


/*
*********************************************************************************************************
*                                 GRAPH LCD PRINT STRING AT POSITION
*********************************************************************************************************
*/

void  BSP_GraphLCD_StringPos (CPU_INT08U   line,
                              CPU_INT08U   pos,
                              CPU_CHAR    *p_str)
{
    CPU_INT08U  x;
    CPU_INT08U  y;


    x = pos  * 5u;
    y = line * 9u;

    GlyphEraseBlock(BSP_GraphLCD, 0u, y, 95u, y + 8u);
    GlyphSetXY     (BSP_GraphLCD, x, y);
    GlyphString    (BSP_GraphLCD, (uint8_t *)p_str, Str_Len(p_str));
}










/*// By Abohmeed
*********************************************************************************************************
*                                         GlyphDrawBlock
*********************************************************************************************************
*/



void  BSP_GraphLCD_DrawBlock (uint32_t aX1, uint32_t aY1, uint32_t aX2, uint32_t aY2, int PixelNo )					// By Abohmeed
{
	GlyphDrawBlock(BSP_GraphLCD,aX1,aY1,aX2,aY2 , PixelNo );										// Here , I made the position variable


}








/*// By Abohmeed
*********************************************************************************************************
*                                         GlyphSetContrast
*********************************************************************************************************
*/



void  BSP_GraphLCD_SetContrast ( int32_t contrast_val )					// By Abohmeed
{
	GlyphSetContrast(BSP_GraphLCD, contrast_val );


}
