
/*
*********************************************************************************************************
*                                             INCLUDE FILES
*********************************************************************************************************
*/

#include <includes.h>
#include "iodefine.h"

#define APP_ACCEL_HYST            10

#define APP_ACCEL_NEG(val,ref)      (val < (ref - APP_ACCEL_HYST))
#define APP_ACCEL_POS(val,ref)      (val > (ref + APP_ACCEL_HYST))
#define APP_ACCEL_ZERO(val,ref)    ((val > (ref - APP_ACCEL_HYST)) && \
                                    (val < (ref + APP_ACCEL_HYST)))

/*
*********************************************************************************************************
*                                            LOCAL VARIABLES
*********************************************************************************************************
*/

static  OS_TCB       AppTaskStartTCB;
static  OS_TCB       AppAccelTaskTCB;

static  OS_TCB       AppAboutTaskTCB;

static  OS_TCB       AppTempTaskTCB;


static  CPU_STK      AppTaskStartStk[APP_TASK_START_STK_SIZE];
static  CPU_STK      AppAccelTaskStk[ACCEL_TASK_STK_SIZE];
static  CPU_STK      AppAboutTaskStk[ABOUT_TASK_STK_SIZE];

static  CPU_BOOLEAN  AppTCPIP_Cfg = DEF_FALSE;


/*
*********************************************************************************************************
*                                         FUNCTION PROTOTYPES
*********************************************************************************************************
*/

static  void  AppTaskStart   (void     *p_arg);
static  void  AppAccelTask   (void     *p_arg);
static  void  AppAboutTask   (void     *p_arg);


static void  AppGraphLCD_DrawBlock (uint32_t AaX1, uint32_t AaY1, uint32_t AaX2, uint32_t AaY2,int PixelNo );   ///  By Abohmeed



static  void  AppADC_Init (void);				//  Init ADC
static  void  AppADC_TmrInit   (void);			// Init ADC Timer
static  void  AppGraphLCD_Hdr (void) ;			// LCD Chars
		void  DrawADI(void) ;
		void  WriteADIValues(void);

void convert_Int_to_Char(int digit);



/*
*********************************************************************************************************
*                                         GLOBAL VARIABLES
*********************************************************************************************************
*/

extern  volatile  CPU_INT16S  BSP_Accel_X_Zero;
extern  volatile  CPU_INT16S  BSP_Accel_Y_Zero;
extern  volatile  CPU_INT16S  BSP_Accel_Z_Zero;

                  CPU_INT08U  AppQuadrant  = 1;
				  
				  CPU_INT08U  AppQuadrant_Z  = 1;
				  
                  CPU_FP32    AppDegrees   = 0.0f;
                  CPU_INT32U  AppMagnitude = 0;
                  CPU_FP32    AppTemp_C    = 0.0f;
                  CPU_FP32    AppTemp_F    = 0.0f;


CPU_FP32    angle_degrees ;

int DegOnes  , DegHundreds , DegTens ;


int FlagAbout = 0  , FlagAboutADIvals = 0  , BufferFlag = 0 ;

CPU_CHAR *OutChar ;


double Pitch ;



/*
*********************************************************************************************************
*                                                main()
*
* Description : This is the standard entry point for C code.  It is assumed that your code will call
*               main() once you have performed all necessary initialization.
*
* Arguments   : none
*
* Returns     : none
*********************************************************************************************************
*/

int  main (void)
{
	
	
    OS_ERR  err;


    CPU_IntDis();                                               /* Disable all interrupts.                              */

    OSInit(&err);                                               /* Init uC/OS-III.                                      */

    App_OS_SetAllHooks();

    OSTaskCreate((OS_TCB     *)&AppTaskStartTCB,                /* Create the start task                                */
                 (CPU_CHAR   *)"App Task Start",
                 (OS_TASK_PTR ) AppTaskStart,
                 (void       *) 0,
                 (OS_PRIO     ) APP_TASK_START_PRIO,
                 (CPU_STK    *)&AppTaskStartStk[0],
                 (CPU_STK_SIZE) APP_TASK_START_STK_SIZE / 10u,
                 (CPU_STK_SIZE) APP_TASK_START_STK_SIZE,
                 (OS_MSG_QTY  ) 0u,
                 (OS_TICK     ) 0u,
                 (void       *) 0,
                 (OS_OPT      )(OS_OPT_TASK_STK_CHK | OS_OPT_TASK_STK_CLR),
                 (OS_ERR     *)&err);

    OSStart(&err);                                              /* Start multitasking (i.e. give control to uC/OS-III). */

    while (1) {
        ;
    }

    return (0);
}

/*
*********************************************************************************************************
*                                          STARTUP TASK
*
* Description : This is an example of a startup task.  As mentioned in the book's text, you MUST
*               initialize the ticker only once multitasking has started.
*
* Arguments   : p_arg   is the argument passed to 'AppTaskStart()' by 'OSTaskCreate()'.
*
* Returns     : none
*
* Notes       : 1) The first line of code is used to prevent a compiler warning because 'p_arg' is not
*                  used.  The compiler should not generate any code for this statement.
*********************************************************************************************************
*/

static  void  AppTaskStart (void *p_arg)
{
    OS_ERR   err;
#if (APP_CFG_TCPIP_MODULE_EN > 0u)
    NET_ERR  net_err;
#endif


   (void)&p_arg;

    BSP_Init();                                                 /* Initialize BSP functions                             */
    CPU_Init();                                                 /* Initialize the uC/CPU services                       */
    OS_CPU_TickInit();                                          /* Init uC/OS periodic time src (SysTick).              */

#if (OS_CFG_STAT_TASK_EN > 0u)
    OSStatTaskCPUUsageInit(&err);                               /* Compute CPU capacity with no task running            */
#endif

    Mem_Init();                                                 /* Initialize mem mgmt module, required for TCP-IP.     */




    BSP_GraphLCD_Init();





    OSTaskCreate((OS_TCB     *)&AppAccelTaskTCB,                /* Create the accelerometer task                        */
                 (CPU_CHAR   *)"Accel Task",
                 (OS_TASK_PTR ) AppAccelTask,
                 (void       *) 0,
                 (OS_PRIO     ) ACCEL_TASK_PRIO,
                 (CPU_STK    *)&AppAccelTaskStk[0],
                 (CPU_STK_SIZE) ACCEL_TASK_STK_SIZE / 10u,
                 (CPU_STK_SIZE) ACCEL_TASK_STK_SIZE,
                 (OS_MSG_QTY  ) 0u,
                 (OS_TICK     ) 0u,
                 (void       *) 0,
                 (OS_OPT      )(OS_OPT_TASK_STK_CHK | OS_OPT_TASK_STK_CLR),
                 (OS_ERR     *)&err);



    BSP_GraphLCD_Init();



#ifdef CPU_CFG_INT_DIS_MEAS_EN
    CPU_IntDisMeasMaxCurReset();
#endif

    AppTCPIP_Cfg = DEF_TRUE;

    while (DEF_ON) {
        OSTimeDlyHMSM(0u, 0u, 0u, 100u,
                      OS_OPT_TIME_HMSM_STRICT,
                      &err);
    }
}

/*
*********************************************************************************************************
*                                          ACCELEROMETER TASK
*
* Description : This task initialises the ADXL345 accelerometer, sets the zero points for
*               the X and Y axis. It then periodically reads the current X and Y values from
*               the accelerometer and calculates the inclination angle and AppMagnitude of the
*               the board. Illuminates the LED corresponding to the direction the board is
*               currently tilted.
*
* Arguments   : p_arg   is the argument passed to 'AppAccelTask()'.
*
* Returns     : none
*
* Notes       : 1) The first line of code is used to prevent a compiler warning because 'p_arg' is not
*                  used.  The compiler should not generate any code for this statement.
*********************************************************************************************************
*/
static  void  AppAccelTask (void *p_arg)
{
    OS_ERR      err;
    CPU_FP32    angle_radians;
    CPU_FP32    angle_degrees;
    CPU_INT16S  accel_x_axis;
    CPU_INT16S  accel_y_axis;
    CPU_INT16S  accel_z_axis;
    CPU_FP32    x;
    CPU_FP32    x2;
    CPU_FP32    y;
    CPU_FP32    y2;
	CPU_FP32    z;										//  By Abohmeed
    CPU_FP32    sum_x2_y2;

	int Delay_Acc ; 



for (  Delay_Acc = 0 ; Delay_Acc < 10000; Delay_Acc  ++ ) ;
	
    (void)&p_arg;

    angle_radians = 0.0f;
    angle_degrees = 0.0f;

    BSP_Accel_Init();                                           /* Initialize the accelerometer                         */
    BSP_Accel_ZeroCal();                                        /* Calibrate  the accelerometer                         */


	AppADC_Init () ;											// Initialize ADC
	AppADC_TmrInit();                                           /* Initialize ADC trigger timer                         */



    LED_Off(0);                                                 /* Turn all LEDs off                                    */

    while (DEF_ON) {
        OSTimeDlyHMSM(0u, 0u, 0u, 100u,
                      OS_OPT_TIME_HMSM_STRICT,
                      &err);

        accel_x_axis = BSP_Accel_X_AxisRd();
        accel_y_axis = BSP_Accel_Y_AxisRd();
        accel_z_axis = BSP_Accel_Z_AxisRd();		
		

        if ((APP_ACCEL_ZERO(accel_x_axis, BSP_Accel_X_Zero)) &&
            (APP_ACCEL_ZERO(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant = 5;                                    /* Board is flat                                        */

        } else if ((APP_ACCEL_NEG (accel_y_axis, BSP_Accel_Y_Zero)) &&
                   (APP_ACCEL_ZERO(accel_x_axis, BSP_Accel_X_Zero))) {
            AppQuadrant = 6;

        } else if ((APP_ACCEL_POS (accel_y_axis, BSP_Accel_Y_Zero)) &&
                   (APP_ACCEL_ZERO(accel_x_axis, BSP_Accel_X_Zero))) {
            AppQuadrant = 7;

        } else if ((APP_ACCEL_POS (accel_x_axis, BSP_Accel_X_Zero)) &&
                   (APP_ACCEL_ZERO(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant = 8;

        } else if ((APP_ACCEL_NEG (accel_x_axis, BSP_Accel_X_Zero)) &&
                   (APP_ACCEL_ZERO(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant = 9;

        } else if ((APP_ACCEL_POS(accel_x_axis, BSP_Accel_X_Zero)) &&
                   (APP_ACCEL_POS(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant = 3;

        } else if ((APP_ACCEL_POS(accel_x_axis, BSP_Accel_X_Zero)) &&
                   (APP_ACCEL_NEG(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant = 4;

        } else if ((APP_ACCEL_NEG(accel_x_axis, BSP_Accel_X_Zero)) &&
                   (APP_ACCEL_POS(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant = 2;

        } else if ((APP_ACCEL_NEG(accel_x_axis, BSP_Accel_X_Zero)) &&
                   (APP_ACCEL_NEG(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant = 1;
        }






        if ((APP_ACCEL_ZERO(accel_z_axis, BSP_Accel_Z_Zero)) &&
            (APP_ACCEL_ZERO(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant_Z = 5;                                    /* Board is flat                                        */

        } else if ((APP_ACCEL_NEG (accel_y_axis, BSP_Accel_Y_Zero)) &&
                   (APP_ACCEL_ZERO(accel_z_axis, BSP_Accel_Z_Zero))) {
            AppQuadrant_Z = 6;

        } else if ((APP_ACCEL_POS (accel_y_axis, BSP_Accel_Y_Zero)) &&
                   (APP_ACCEL_ZERO(accel_z_axis, BSP_Accel_Z_Zero))) {
            AppQuadrant_Z = 7;

        } else if ((APP_ACCEL_POS (accel_z_axis, BSP_Accel_Z_Zero)) &&
                   (APP_ACCEL_ZERO(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant_Z = 8;

        } else if ((APP_ACCEL_NEG (accel_z_axis, BSP_Accel_Z_Zero)) &&
                   (APP_ACCEL_ZERO(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant_Z = 9;

        } else if ((APP_ACCEL_POS(accel_z_axis, BSP_Accel_Z_Zero)) &&
                   (APP_ACCEL_POS(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant_Z = 3;

        } else if ((APP_ACCEL_POS(accel_z_axis, BSP_Accel_Z_Zero)) &&
                   (APP_ACCEL_NEG(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant_Z = 4;

        } else if ((APP_ACCEL_NEG(accel_z_axis, BSP_Accel_Z_Zero)) &&
                   (APP_ACCEL_POS(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant_Z = 2;

        } else if ((APP_ACCEL_NEG(accel_z_axis, BSP_Accel_Z_Zero)) &&
                   (APP_ACCEL_NEG(accel_y_axis, BSP_Accel_Y_Zero))) {
            AppQuadrant_Z = 1;
        }




        x            = accel_x_axis;
        y            = accel_y_axis;
		z            = accel_z_axis;
        x           -= BSP_Accel_X_Zero;                        /* Normalize                                            */
        y           -= BSP_Accel_Y_Zero;
		z           -= BSP_Accel_Z_Zero;


        x2           = x * x;
        y2           = y * y;
        sum_x2_y2    = x2 + y2;
        AppMagnitude = sqrt(sum_x2_y2 / 2.0f);


//	Pitch =   ( 20 * z / y ) + 15 ;   //  	original location

	
	double slope  =   x / y   ;				//	 This is slope calculated from ( x / y )


	CPU_INT16U  temp;

	volatile  CPU_FP32    knob        =   3.6f;

			

 BSP_GraphLCD_SetContrast( ( S12AD.ADDRE / 205 ) + 90  ) ;


	
	
	if ( PORT4.PORT.BIT.B1 == 0 )	
		 
		 {		BufferFlag ++ ; 	

		 		if ( BufferFlag == 3 )    {  FlagAbout ++ ;   BufferFlag = 0 ; } 
		 
		 	 
		 				if(	FlagAbout == 2	)	 {	FlagAbout = 0 ;	FlagAboutADIvals = 0 ; }		 } 
 
 
	if ( FlagAbout == 1 ) 	 {	BSP_GraphLCD_Clear();	AppGraphLCD_Hdr(); 	 }




if(  FlagAbout == 1 )	


{	goto  MyLable	;   }




//////////////////////////////////////////////////////////////////////////////
//////////////////		DRAW ADI 



	if (  ( AppQuadrant == 1 ) || ( AppQuadrant == 4 ) || ( AppQuadrant == 6 )  )


{


///////////////////////////////////////////////////////////////////////////////////
//  This is the up-side down situation
///////////////////////////////////////////////////////////////////////////////////

	int column  , line  , WindowColumn , WindowLine , line0,  Pixel=  -1 , PixelFill ,   PixelNo  = 0 , DelayToDraw , PixelFillLine1 , PixelFillHoriz , PixelFillCircle , PixelFillFrame , Last_Line, Last_Column; 
	

	for ( column  = -48  ;  column  <  48 ; column ++   )
	
		{		
			PixelFillHoriz = 0 ;
						
			for ( line  =  32  ;  line  > - 32 ; line  --   )
			{
			Pixel ++ ;


	Pitch =   ( 20 * z / y ) - 15 ;
						
		line0 = ( slope * column  ) - Pitch ;
			
		
		PixelFillLine1 = 0x00 ;
		PixelFillCircle = 0x00 ;

		if ( column < 20 & column > -20   & line  ==  - 19  ) { PixelFillLine1 = 0x01 ;}	//	Upper line 2 
		
		if ( column < 10 & column > -10   & line  == - 9  ) { PixelFillLine1 = 0x01 ;}		//	Upper line 1

		if ( column < 10 & column > -10   & line  ==  11  ) { PixelFillLine1 = 0x01 ;}		//	Lower line 1

		if ( column < 20 & column > -20   & line  ==  21  ) { PixelFillLine1 = 0x01 ;}		//	Lower line 2


		if ( column < 48 & column > -49   & line  ==  0  ) { PixelFillLine1 = 0x01 ;}		//	Lower line 2
	


		if ( column < 48 & column > - 49   & line  ==  -31 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48 & column > - 49   & line  ==  -30 ) { PixelFillCircle  = 0x01 ;}		//	circle line 1
		if ( column < 48 & column > - 49   & line  ==  -29 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48 & column > - 49   & line  ==  -28 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -29 & column > - 49   & line  ==  -27 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   28   & line  ==  -27 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -31 & column > - 49   & line  ==  -26 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   30   & line  ==  -26 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -33 & column > - 49   & line  ==  -25 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   32   & line  ==  -25 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -24 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -24 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -23 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -23 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -22 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -22 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -21 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -21 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -20 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -20 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -19 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -19 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -18 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -18 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -17 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -17 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -16 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -16 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -15 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -15 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -14 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -14 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -13 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -13 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -12 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -12 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -11 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -11 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -10 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -10 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -9 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -9 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -8 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -8 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -7 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -7 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -6 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -6 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -5 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -5 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -4 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -4 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -3 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -3 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -2 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -2 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -1 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  -1 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==   0 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==   0 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

////////////////////////////////////////////////////////////////////////////////


		if ( column < 48 & column > - 49   & line  ==  32 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48 & column > - 49   & line  ==  31 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48 & column > - 49   & line  ==  30 ) { PixelFillCircle  = 0x01 ;}		//	circle line 1
		if ( column < 48 & column > - 49   & line  ==  29 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -29 & column > - 49   & line  ==  28 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   28   & line  ==  28 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -31 & column > - 49   & line  ==  27 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   30   & line  ==  27 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -33 & column > - 49   & line  ==  26 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   32   & line  ==  26 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  25 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  25 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  24 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  24 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  23 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  23 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  22 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  22 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  21 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  21 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  20 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  20 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  19 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  19 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  18 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  18 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  17 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  17 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  16 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  16 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  15 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  15 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  14 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  14 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  13 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  13 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  12 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  12 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  11 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  11 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  10 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  10 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  9 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  9 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  8 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  8 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  7 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  7 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  6 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  6 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  5 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  5 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  4 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  4 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  3 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  3 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  2 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  2 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  1 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  1 ) { PixelFillCircle  = 0x01 ;}		//	circle line 2




		if ( (line0 < ( line + 0.5 ) ) && ( line0 > ( line - 0.5 )  ) ) { PixelFillHoriz =  0x01 ;}	




		PixelFillFrame  = 0x00 ;


		if ( line < 25 & line > - 24   & column  ==  -34 ) { PixelFillFrame  = 0x80 ; }		//	Inner Frame Vertical line
		if ( line < 25 & line > - 24   & column  ==   33 ) { PixelFillFrame  = 0x80 ; }		//	Inner Frame Vertical line

		if ( column < 29 & column > - 30   & line  ==  -27 ) { PixelFillFrame  = 0x80 ;}	//	Inner Frame Horizontal line
		if ( column < 29 & column > - 30   & line  ==   28 ) { PixelFillFrame  = 0x80 ;}	//	Inner Frame Horizontal line



		if ( column < -29 & column > - 32   & line  ==  -26 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper left
		if ( column < -30 & column > - 33   & line  ==  -25 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper left
		if ( column == -33   & line  ==  -24 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper left

		if ( column <  31 & column >   28   & line  ==  -26 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper Right
		if ( column <  32 & column >   29   & line  ==  -25 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper Right
		if ( column == 32   & line  ==  -24 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper Right


		if ( column < -29 & column > - 32   & line  ==  27 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Lower left
		if ( column < -30 & column > - 33   & line  ==  26 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Lower left
		if ( column == -33   & line  ==  25 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper left

		if ( column <  31 & column >   28   & line  ==  27 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Lower Right
		if ( column <  32 & column >   29   & line  ==  26 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Lower Right
		if ( column == 32   & line  ==  25 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper Right
		





	PixelFill = 0 ;


	if (  PixelFillLine1  == 0x01 )   {	PixelFill = 0x01 ;  }
	
	if (  PixelFillHoriz  == 0x01 )   {	PixelFill = 0x01 ;  }

	if (	PixelFillLine1  == PixelFillHoriz )		{		PixelFill = 0x00 ;		}
	
	
		if (  PixelFillCircle  == 0x01 )   {	PixelFill = 0x01 ;  }


		if ( PixelFillFrame == 0x80 ) 			PixelFill = 0x00 ; 

		
		PixelNo = ( PixelNo * 2 ) + PixelFill  ; 

			
			if ( Pixel == 7  )
				{
					
				for (  DelayToDraw = 0 ;  DelayToDraw < 9000 ; DelayToDraw ++ )	 ;
					
				WindowColumn = column + 48 ;
				
				WindowLine = line + 32 ;
						
				AppGraphLCD_DrawBlock( WindowColumn , WindowLine , WindowColumn , WindowLine , PixelNo  ); 		// Added By Abohmeed  ( column , line , column , line , PixelNum )  								
					
				PixelNo = 0 ;	
			
				Pixel = -1 ;
			}
		}
	}

///////////////////////////////////////////////////////////////////////////////////

}




else

{

///////////////////////////////////////////////////////////////////////////////////		
// This is the normal situation	
///////////////////////////////////////////////////////////////////////////////////

	int column  , line  , WindowColumn , WindowLine , line0,  Pixel=  -1 , PixelFill ,   PixelNo  = 0 , DelayToDraw , PixelFillLine1 , PixelFillHoriz , PixelFillCircle , PixelFillFrame  , Last_Line, Last_Column;  
	

	for ( column  = -48  ;  column  <  48 ; column ++   )
	
		{		
			PixelFillHoriz = 0 ;
						
			for ( line  =  -32  ;  line  < 32 ; line  ++   )
			{
			Pixel ++ ;
			
				
					

	Pitch =   ( 20 * z / y ) + 15 ;

		line0 = ( slope * column  ) - Pitch ;
			
					
		PixelFillLine1 = 0x00 ;

		PixelFillCircle = 0x00 ;
		
		if ( (line0 < ( line + 0.5 ) ) && ( line0 > ( line - 0.5 )  ) ) { PixelFillHoriz =  0x80 ;}	
		

	

		
		if ( column < 20 & column > -20   & line  ==  - 20  ) { PixelFillLine1 = 0x80 ;}	//	Upper line 2 
		
		if ( column < 10 & column > -10   & line  == - 10  ) { PixelFillLine1 = 0x80 ;}		//	Upper line 1

		if ( column < 10 & column > -10   & line  ==  10  ) { PixelFillLine1 = 0x80 ;}		//	Lower line 1

		if ( column < 20 & column > -20   & line  ==  20  ) { PixelFillLine1 = 0x80 ;}		//	Lower line 2




		if ( column < 48 & column > -49   & line  ==  - 1  ) { PixelFillLine1 = 0x80 ;}		//	Middle line
		
		
		

		if ( column < 48 & column > - 49   & line  ==  -32 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column > - 49   & line  ==  -31 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column > - 49   & line  ==  -30 ) { PixelFillCircle  = 0x80 ;}		//	circle line 1
		if ( column < 48 & column > - 49   & line  ==  -29 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		
		if ( column < -29 & column > - 49   & line  ==  -28 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   28   & line  ==  -28 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -31 & column > - 49   & line  ==  -27 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   30   & line  ==  -27 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -33 & column > - 49   & line  ==  -26 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   32   & line  ==  -26 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -25 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -25 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -24 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -24 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -23 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -23 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -22 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -22 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -21 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -21 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -20 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -20 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -19 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -19 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -18 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -18 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -17 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -17 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -16 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -16 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -15 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -15 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -14 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -14 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

//////////////////////////////


		if ( column < -34 & column > - 49   & line  ==  -13 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -13 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -12 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -12 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -11 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -11 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -10 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -10 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -9 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -9 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -8 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -8 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -7 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -7 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -6 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -6 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -5 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -5 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -4 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -4 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -3 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -3 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  -2 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -2 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2


		if ( column < -34 & column > - 49   & line  ==  -1 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  -1 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  0 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column  >   33   & line  ==  0 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2


//////////***********************************************************

		if ( column < 48 & column > - 49   & line  ==  31 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column > - 49   & line  ==  30 ) { PixelFillCircle  = 0x80 ;}		//	circle line 1
		if ( column < 48 & column > - 49   & line  ==  29 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48 & column > - 49   & line  ==  28 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		
		if ( column < -29 & column > - 49   & line  ==  27 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   28   & line  ==  27 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -31 & column > - 49   & line  ==  26 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   30   & line  ==  26 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -33 & column > - 49   & line  ==  25 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   32   & line  ==  25 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  24 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  24 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  23 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  23 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  22 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  22 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  21 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  21 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2


		if ( column < -34 & column > - 49   & line  ==  20 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  20 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  19 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  19 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  18 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  18 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  17 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  17 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  16 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  16 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  15 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  15 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  14 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  14 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  13 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  13 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  12 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  12 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  11 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  11 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  10 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  10 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  9 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  9 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  8 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  8 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  7 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  7 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  6 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  6 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  5 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  5 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  4 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  4 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  3 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  3 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  2 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  2 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2

		if ( column < -34 & column > - 49   & line  ==  1 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2
		if ( column < 48  & column >   33   & line  ==  1 ) { PixelFillCircle  = 0x80 ;}		//	circle line 2



		PixelFillFrame  = 0x00 ;


		if ( line < 24 & line > - 25   & column  ==  -34 ) { PixelFillFrame  = 0x80 ; }		//	Inner Frame Vertical line
		if ( line < 24 & line > - 25   & column  ==   33 ) { PixelFillFrame  = 0x80 ; }		//	Inner Frame Vertical line

		if ( column < 29 & column > - 30   & line  ==  -28 ) { PixelFillFrame  = 0x80 ;}	//	Inner Frame Horizontal line
		if ( column < 29 & column > - 30   & line  ==   27 ) { PixelFillFrame  = 0x80 ;}	//	Inner Frame Horizontal line


		if ( column < -29 & column > - 32   & line  ==  -27 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper left
		if ( column < -30 & column > - 33   & line  ==  -26 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper left
		if ( column == -33   & line  ==  -25 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper left

		if ( column <  31 & column >   28   & line  ==  -27 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper Right
		if ( column <  32 & column >   29   & line  ==  -26 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper Right
		if ( column == 32   & line  ==  -25 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper Right


		if ( column < -29 & column > - 32   & line  ==  26 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Lower left
		if ( column < -30 & column > - 33   & line  ==  25 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Lower left
		if ( column == -33   & line  ==  24 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper left

		if ( column <  31 & column >   28   & line  ==  26 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Lower Right
		if ( column <  32 & column >   29   & line  ==  25 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Lower Right
		if ( column == 32   & line  ==  24 ) { PixelFillFrame  = 0x80 ;}	//	Corner Frame Upper Right
		

	PixelFill = 0 ;


	if (  PixelFillLine1  == 0x80 )   {	PixelFill = 0x80 ;  }
	
	if (  PixelFillHoriz  == 0x80 )   {	PixelFill = 0x80 ;  }
	

	if (	PixelFillLine1  == PixelFillHoriz )		{		PixelFill = 0x00 ;		}
	
	if (  PixelFillCircle  == 0x80 )   {	PixelFill = 0x80 ;  }

	if ( PixelFillFrame == 0x80 ) 		{	PixelFill = 0x00 ; 	}
		

	PixelNo = ( PixelNo / 2 ) + PixelFill  ; 

			
			if ( Pixel == 7  )
				{
					
				for (  DelayToDraw = 0 ;  DelayToDraw < 9000 ; DelayToDraw ++ )	 ;
					
				WindowColumn = column + 48 ;
				
				WindowLine = line + 32 ;
						
				AppGraphLCD_DrawBlock( WindowColumn , WindowLine , WindowColumn , WindowLine , PixelNo  ); 		// Added By Abohmeed  ( column , line , column , line , PixelNum )  								
					
				PixelNo = 0 ;	
			
				Pixel = -1 ;
			}
		}
	}

///////////////////////////////////////////////////////////////////////////////////

}	


MyLable: 	

temp = 5 ;
 






        if ((fabs(x) > 0.5f) &&                                 /* Both axis are greater than zero.                     */
            (fabs(y) > 0.5f)) {
            angle_radians = atan2(fabs(x), fabs(y));
            angle_degrees = (angle_radians * 180.0f) / 3.1415926535897932f;
        }

        if (AppQuadrant == 5) {
            AppDegrees = 0.0f;
            if (AppTCPIP_Cfg == DEF_TRUE) {
                LED_On( 4);                                     /* Turn on all LEDs when the board is flat and ...      */
                LED_On( 5);                                     /* ... TCP-IP initialization is complete.               */
                LED_On( 6);
                LED_On( 7);
                LED_On( 8);
                LED_On( 9);
                LED_On(10);
                LED_On(11);
                LED_On(12);
                LED_On(13);
                LED_On(14);
                LED_On(15);

            } else {

                LED_On ( 4);                                    /* Turn on half of the LEDs to show that TCP-IP ...     */
                LED_Off( 5);                                    /* ... initialization is NOT yet complete.              */
                LED_On ( 6);
                LED_Off( 7);
                LED_On ( 8);
                LED_Off( 9);
                LED_On (10);
                LED_Off(11);
                LED_On (12);
                LED_Off(13);
                LED_On (14);
                LED_Off(15);
            }

        } else {

            LED_Off(0);                                         /* Turn off all LEDs                                    */

            switch (AppQuadrant) {
                case 1:
                     AppDegrees = angle_degrees;
                     if (angle_degrees < 30.0f) {
                         LED_On(4);
                     } else if (angle_degrees < 60.0f) {
                         LED_On(5);
                     } else {
                         LED_On(6);
                     }
                     break;


                case 2:
                     AppDegrees = 180.0f - angle_degrees;
                     if (angle_degrees < 30.0f) {
                         LED_On(9);
                     } else if (angle_degrees < 60.0f) {
                         LED_On(8);
                     } else {
                         LED_On(7);
                     }
                     break;


                case 3:
                     AppDegrees = angle_degrees + 180.0f;
                     if (angle_degrees < 30.0f) {
                         LED_On(10);
                     } else if( angle_degrees < 60.0f) {
                         LED_On(11);
                     } else {
                         LED_On(12);
                     }
                     break;


                case 4:
                     AppDegrees = 360.0f - angle_degrees;
                     if (angle_degrees < 30.0f) {
                         LED_On(15);
                     } else if (angle_degrees < 60.0f) {
                         LED_On(14);
                     } else {
                         LED_On(13);
                     }
                     break;


                case 6:
                     AppDegrees = 0.0f;
                     LED_On(4);
                     break;


                case 7:
                     AppDegrees = 180.0f;
                     LED_On(10);
                     break;


                case 8:
                     AppDegrees = 270.0f;
                     LED_On(13);
                     break;


                case 9:
                     AppDegrees =  90.0f;
                     LED_On(7);
                     break;
            }
        }
    }



	
}










/*   WRitten by ABOHmeed
*********************************************************************************************************
*                                          AppGraphLCD_DrawBlock()
*********************************************************************************************************
*/

static  void  AppGraphLCD_DrawBlock (uint32_t AaX1, uint32_t AaY1, uint32_t AaX2, uint32_t AaY2 ,int PixelNo )    ///     Added By Abohmeed
{
	BSP_GraphLCD_DrawBlock ( AaX1 , AaY1 , AaX2 , AaY2 , PixelNo  );			// By Abohmeed
}



/*
*********************************************************************************************************
*                                           AppADC_TmrInit()
*
* Description : Function to initialise MTU channel 0 to operate in normal mode. This timer triggers ADC 
*               conversions.
*
* Arguments   : none
*
* Returns     : none
*
* Notes       : none
*********************************************************************************************************
*/

static  void  AppADC_TmrInit (void)
{
    MSTP_MTU0          = 0;                                     /* Enable MTU0 - disable module stop mode               */

    MTU0.TCR.BIT.TPSC  = 3;                                     /* Internal Pclk/64   clock source                      */
    MTU0.TCR.BIT.CCLR  = 1;                                     /* Counter cleared on TGRA compare match                */

    MTU0.TMDR.BIT.MD   = 0;                                     /* Normal mode                                          */

                                                                /* Compare match value - 512 Hz                         */
    MTU0.TGRA          = (CPU_INT16U)((BSP_CPU_EXT_CLK_FREQ * 4) / (64 * 512));

    MTU0.TIER.BIT.TTGE = 1;                                     /* ADC converter start request                          */

    MTUA.TSTR.BIT.CST0 = 1;                                     /* Start timer                                          */
}

/*
*********************************************************************************************************
*                                             AppADC_Init()
*
* Description : Function to initialise ADC 1.
*               Conversion triggered by MTU2
*
* Arguments   : none
*
* Returns     : none
*
* Notes       : AN4 - Input from POT1
*             : AN7 - Input from MTU2 generated sine wave
*
*********************************************************************************************************
*/
static  void  AppADC_Init (void)
{
    MSTP_S12AD               = 0;                               /* Enable S12AD 12-bit ADC - disable module stop mode   */

    S12AD.ADCSR.BIT.ADST     = 0;                               /* Stop ADC                                             */
    S12AD.ADCSR.BIT.ADCS     = 0;                               /* Single-scan mode                                     */
    S12AD.ADCSR.BIT.ADIE     = 1;                               /* Conversion interrupt enabled                         */
    S12AD.ADCSR.BIT.TRGE     = 1;                               /* Trigger by external source                           */
    S12AD.ADCSR.BIT.EXTRG    = 0;                               /* Trigger by MTU2 or MTU2S                             */

    S12AD.ADANS.BIT.ANS      = (1 << 4) | (1 << 7);             /* Enable AN4 & AN7 channels                            */

    IPR(S12AD, ADI)          = 3;                               /* Set interrupt priority.                              */
    IEN(S12AD, ADI)          = 1;                               /* Enable interrupt source.                             */

    S12AD.ADSTRGR.BIT.ADSTRS = 1;                               /* Trigger by MTU0 compare match A                      */

    PORT4.ICR.BIT.B4         = 1;                               /* P44 input routed to peripheral                       */
    PORT4.ICR.BIT.B7         = 1;                               /* P47 input routed to peripheral                       */
}




/*
*********************************************************************************************************
*                                          AppGraphLCD_Hdr()
*********************************************************************************************************
*/

static  void  AppGraphLCD_Hdr (void)
{


    BSP_GraphLCD_SetFont(BSP_GLCD_FONT_LARGE);
    BSP_GraphLCD_StringPos(1, 0, "MicroMonitor");

    BSP_GraphLCD_SetFont(BSP_GLCD_FONT_SMALL);
    BSP_GraphLCD_StringPos(2, 4, "GyroHorizon");

    BSP_GraphLCD_SetFont(BSP_GLCD_FONT_SMALL);
    BSP_GraphLCD_StringPos(4, 0, "Creadits:");

    BSP_GraphLCD_SetFont(BSP_GLCD_FONT_SMALL);
    BSP_GraphLCD_StringPos(6, 4, "MOHAMED EBEED");

    BSP_GraphLCD_SetFont(BSP_GLCD_FONT_SMALL);
    BSP_GraphLCD_StringPos(7, 4, "AHMED EBEED");



}
