;********************************************************************************************************
;                                                uC/CPU
;                                    CPU CONFIGURATION & PORT LAYER
;
;                          (c) Copyright 2004-2010; Micrium, Inc.; Weston, FL
;
;               All rights reserved.  Protected by international copyright laws.
;
;               uC/CPU is provided in source form to registered licensees ONLY.  It is 
;               illegal to distribute this source code to any third party unless you receive 
;               written permission by an authorized Micrium representative.  Knowledge of 
;               the source code may NOT be used to develop a similar product.
;
;               Please help us continue to provide the Embedded community with the finest 
;               software available.  Your honesty is greatly appreciated.
;
;               You can contact us at www.micrium.com.
;********************************************************************************************************

;********************************************************************************************************
;
;                                            CPU PORT FILE
;
;                                              TEMPLATE
;
;                                         $$$$ Insert CPU Name
;                                      $$$$ Insert Compiler Name
;
; Filename      : cpu_a.asm            $$$$ Insert CPU assembly port file name
; Version       : V1.26                $$$$ Insert CPU assembly port file version number
; Programmer(s) : ITJ                  $$$$ Insert CPU assembly port file programmer(s) initials
;********************************************************************************************************
; Note(s)       : (1) To provide the required CPU port functionality, insert the appropriate CPU- &/or
;                     compiler-specific code to perform the stated actions wherever '$$$$' comments are
;                     found.
;
;                     #### This note MAY be entirely removed for specific CPU port files.
;********************************************************************************************************


;********************************************************************************************************
;                                           PUBLIC FUNCTIONS
;********************************************************************************************************

                                ; $$$$ Extern required CPU port functions :
    PUBLIC  CPU_SR_Save
    PUBLIC  CPU_SR_Restore

    PUBLIC  CPU_IntDis
    PUBLIC  CPU_IntEn


;********************************************************************************************************
;                                                EQUATES
;********************************************************************************************************

                                ; $$$$ Define possible required CPU equates :


;********************************************************************************************************
;                                      CODE GENERATION DIRECTIVES
;********************************************************************************************************

                                ; $$$$ Insert possible required CPU-compiler code generation directives :


;$PAGE
;********************************************************************************************************
;                                      DISABLE/ENABLE INTERRUPTS
;
; Description : Disable/Enable interrupts.
;
;               (1) (a) For CPU_CRITICAL_METHOD_INT_DIS_EN, interrupts are enabled/disabled WITHOUT saving
;                       or restoring the state of the interrupt status.
;
;
; Prototypes  : void  CPU_IntDis(void);
;               void  CPU_IntEn (void);
;********************************************************************************************************

CPU_IntDis
                                ; $$$$ Insert code to disable CPU interrupts


CPU_IntEn
                                ; $$$$ Insert code to enable  CPU interrupts


;$PAGE
;********************************************************************************************************
;                                    PUSH/POP CPU STATUS REGISTER
;
; Description : Push/Pop the state of CPU interrupts onto the local stack, if possible.
;
;               (1) (b) For CPU_CRITICAL_METHOD_STATUS_STK, the state of the interrupt status flag is
;                       stored in onto the local stack & interrupts are then disabled.  The previous
;                       interrupt status state is restored from the local stack into the CPU's status
;                       register.
;
;
; Prototypes  : void  CPU_SR_Push(void);
;               void  CPU_SR_Pop (void);
;********************************************************************************************************

CPU_SR_Push
                                ; $$$$ Insert code to push CPU status onto local stack & disable interrupts


CPU_SR_Pop
                                ; $$$$ Insert code to pop  CPU status from local stack


;$PAGE
;********************************************************************************************************
;                                  SAVE/RESTORE CPU STATUS REGISTER
;
; Description : Save/Restore the state of CPU interrupts, if possible.
;
;               (1) (c) For CPU_CRITICAL_METHOD_STATUS_LOCAL, the state of the interrupt status flag is
;                       stored in the local variable 'cpu_sr' & interrupts are then disabled ('cpu_sr' is
;                       allocated in all functions that need to disable interrupts).  The previous interrupt
;                       status state is restored by copying 'cpu_sr' into the CPU's status register.
;
;
; Prototypes  : CPU_SR  CPU_SR_Save   (void);
;               void    CPU_SR_Restore(CPU_SR  cpu_sr);
;
; Note(s)     : (1) These functions are used in general like this :
;
;                       void  Task (void  *p_arg)
;                       {
;                           CPU_SR_ALLOC();                     /* Allocate storage for CPU status register */
;                               :
;                               :
;                           CPU_CRITICAL_ENTER();               /* cpu_sr = CPU_SR_Save();                  */
;                               :
;                               :
;                           CPU_CRITICAL_EXIT();                /* CPU_SR_Restore(cpu_sr);                  */
;                               :
;                       }
;********************************************************************************************************

CPU_SR_Save
                                ; $$$$ Insert code to save    CPU status register(s) & disable interrupts


CPU_SR_Restore
                                ; $$$$ Insert code to restore CPU status register(s)


;$PAGE
;********************************************************************************************************
;                                         CPU_CntLeadZeros()
;
; Description : Count the number of contiguous, most-significant, leading zero bits in a data value.
;
; Prototype   : CPU_DATA  CPU_CntLeadZeros(CPU_DATA  val);
;
; Argument(s) : val         Data value to count leading zero bits.
;
; Return(s)   : Number of contiguous, most-significant, leading zero bits in 'val', if NO error(s).
;
;               0,                                                                  otherwise.
;
; Caller(s)   : Application.
;
;               This function is an INTERNAL CPU module function but MAY be called by application 
;               function(s).
;
; Note(s)     : (1) (a) Supports the following data value sizes :
;
;                       (1)  8-bits
;                       (2) 16-bits
;                       (3) 32-bits
;
;                       See also 'cpu_def.h  CPU WORD CONFIGURATION  Note #1'.
;
;                   (b) (1) For  8-bit values :
;
;                                  b07  b06  b05  b04  b03  b02  b01  b00    # Leading Zeros
;                                  ---  ---  ---  ---  ---  ---  ---  ---    ---------------
;                                   1    x    x    x    x    x    x    x            0
;                                   0    1    x    x    x    x    x    x            1
;                                   0    0    1    x    x    x    x    x            2
;                                   0    0    0    1    x    x    x    x            3
;                                   0    0    0    0    1    x    x    x            4
;                                   0    0    0    0    0    1    x    x            5
;                                   0    0    0    0    0    0    1    x            6
;                                   0    0    0    0    0    0    0    1            7
;                                   0    0    0    0    0    0    0    0            8
;
;
;                       (2) For 16-bit values :
;
;                             b15  b14  b13  ...  b04  b03  b02  b01  b00    # Leading Zeros
;                             ---  ---  ---       ---  ---  ---  ---  ---    ---------------
;                              1    x    x         x    x    x    x    x            0
;                              0    1    x         x    x    x    x    x            1
;                              0    0    1         x    x    x    x    x            2
;                              :    :    :         :    :    :    :    :            :
;                              :    :    :         :    :    :    :    :            :
;                              0    0    0         1    x    x    x    x           11
;                              0    0    0         0    1    x    x    x           12
;                              0    0    0         0    0    1    x    x           13
;                              0    0    0         0    0    0    1    x           14
;                              0    0    0         0    0    0    0    1           15
;                              0    0    0         0    0    0    0    0           16
;
;
;                       (3) For 32-bit values :
;
;                             b31  b30  b29  ...  b04  b03  b02  b01  b00    # Leading Zeros
;                             ---  ---  ---       ---  ---  ---  ---  ---    ---------------
;                              1    x    x         x    x    x    x    x            0
;                              0    1    x         x    x    x    x    x            1
;                              0    0    1         x    x    x    x    x            2
;                              :    :    :         :    :    :    :    :            :
;                              :    :    :         :    :    :    :    :            :
;                              0    0    0         1    x    x    x    x           27
;                              0    0    0         0    1    x    x    x           28
;                              0    0    0         0    0    1    x    x           29
;                              0    0    0         0    0    0    1    x           30
;                              0    0    0         0    0    0    0    1           31
;                              0    0    0         0    0    0    0    0           32
;
;
;                       See also 'CPU COUNT LEAD ZEROs LOOKUP TABLE  Note #1'.
;
;               (2) MUST be implemented in cpu_a.asm if and only if CPU_CFG_LEAD_ZEROS_ASM_PRESENT 
;                   is #define'd in 'cpu_cfg.h' or 'cpu.h'.
;********************************************************************************************************
;$PAGE

CPU_CntLeadZeros

                                ; $$$$ Insert code to count the number of contiguous, most-significant, ...
                                ; ... leading zero bits in 'val' (see Note #1b)


;$PAGE
;********************************************************************************************************
;                                     CPU ASSEMBLY PORT FILE END
;********************************************************************************************************

                                ; $$$$ Insert assembly end-of-file directive, if any

