/*
*********************************************************************************************************
*                                             uC/TCP-IP V2
*                                      The Embedded TCP/IP Suite
*
*                          (c) Copyright 2003-2010; Micrium, Inc.; Weston, FL
*
*               All rights reserved.  Protected by international copyright laws.
*
*               uC/TCP-IP is provided in source form to registered licensees ONLY.  It is 
*               illegal to distribute this source code to any third party unless you receive 
*               written permission by an authorized Micrium representative.  Knowledge of 
*               the source code may NOT be used to develop a similar product.
*
*               Please help us continue to provide the Embedded community with the finest 
*               software available.  Your honesty is greatly appreciated.
*
*               You can contact us at www.micrium.com.
*********************************************************************************************************
*/

/*
*********************************************************************************************************
*
*                                  NETWORK DEVICE CONFIGURATION FILE
*
*                                              TEMPLATE
*
* Filename      : net_dev_cfg.h
* Version       : V2.10
* Programmer(s) : EHS
*                 FGK
*                 ITJ
*********************************************************************************************************
*/


/*
*********************************************************************************************************
*                                               MODULE
*
* Note(s) : (1) This network device configuration header file is protected from multiple pre-processor
*               inclusion through use of the network module present pre-processor macro definition.
*********************************************************************************************************
*/

#ifndef  NET_DEV_CFG_MODULE_PRESENT                             /* See Note #1.                                         */
#define  NET_DEV_CFG_MODULE_PRESENT


/*$PAGE*/
/*
*********************************************************************************************************
*                                    NETWORK DEVICE CONFIGURATION
*
* Note(s) : (1) (a) Each network device maps to a unique, developer-configured device configuration that 
*                   MUST be defined in application files, typically 'net_dev_cfg.c', & SHOULD be forward-
*                   declared with the exact same name & type in order to be used by the application during 
*                   calls to NetIF_Add().
*
*               (b) Since these device configuration structures are referenced ONLY by application files, 
*                   there is NO required naming convention for these configuration structures.  However, 
*                   the following naming convention is suggested for all developer-configured network 
*                   device configuration structures :
*
*                       NetDev_Cfg_<Device>[_Number]
*
*                           where
*                                   <Device>        Name of device or device driver
*                                   [Number]        Network device number for each specific instance of 
*                                                       device (optional if the development board does NOT 
*                                                       support multiple instances of the specific device)
*
*                       Examples :
*
*                           NET_DEV_CFG_ETHER  NetDev_Cfg_MACB;     Ethernet configuration for MACB
*
*                           NET_DEV_CFG_ETHER  NetDev_Cfg_FEC_0;    Ethernet configuration for FEC #0
*                           NET_DEV_CFG_ETHER  NetDev_Cfg_FEC_1;    Ethernet configuration for FEC #1
*
*                           NET_DEV_CFG_PPP    NetDev_Cfg_UART_2;   PPP      configuration for UART #2
*********************************************************************************************************
*/

                                                        /* Declare each specific devices' configuration (see Note #1) : */
#ifdef  NET_IF_MODULE_ETHER_PRESENT

extern  const  NET_DEV_CFG_ETHER  NetDev_Cfg_A_1;       /*   Example Ethernet     configuration for device A, #1        */
extern  const  NET_PHY_CFG_ETHER  NetPhy_Cfg_A_1;       /*   Example Ethernet Phy configuration for device A, #1        */

extern  const  NET_DEV_CFG_ETHER  NetDev_Cfg_A_2;       /*   Example Ethernet     configuration for device A, #2        */
extern  const  NET_PHY_CFG_ETHER  NetPhy_Cfg_A_2;       /*   Example Ethernet Phy configuration for device A, #2        */

#endif


#ifdef  NET_IF_MODULE_PPP_PRESENT                       /* #### NOT yet implemented.                                    */
extern  const  NET_DEV_CFG_PPP    NetDev_Cfg_B_1;       /*   Example PPP          configuration for device B, #1        */
#endif


/*$PAGE*/
/*
*********************************************************************************************************
*                                             MODULE END
*********************************************************************************************************
*/

#endif                                                          /* End of net dev cfg module include.                   */

