/*
*********************************************************************************************************
*                                             uC/TCP-IP V2
*                                      The Embedded TCP/IP Suite
*
*                          (c) Copyright 2003-2010; Micrium, Inc.; Weston, FL
*
*               All rights reserved.  Protected by international copyright laws.
*
*               uC/TCP-IP is provided in source form to registered licensees ONLY.  It is 
*               illegal to distribute this source code to any third party unless you receive 
*               written permission by an authorized Micrium representative.  Knowledge of 
*               the source code may NOT be used to develop a similar product.
*
*               Please help us continue to provide the Embedded community with the finest 
*               software available.  Your honesty is greatly appreciated.
*
*               You can contact us at www.micrium.com.
*********************************************************************************************************
*/

/*
*********************************************************************************************************
*
*                                         NETWORK DATA TYPES
*
* Filename      : net_type.h
* Version       : V2.10
* Programmer(s) : ITJ
*                 SR
*********************************************************************************************************
*/


/*$PAGE*/
/*
*********************************************************************************************************
*                                             DATA TYPES
*********************************************************************************************************
*/

/*
*********************************************************************************************************
*                                            NETWORK TYPE
*
* Note(s) : (1) 'NET_TYPE' declared as 'CPU_INT32U' & all 'NET_TYPE's #define'd with large, non-trivial
*               values to trap & discard invalid/corrupted network objects based on 'NET_TYPE'.
*********************************************************************************************************
*/

typedef  CPU_INT32U  NET_TYPE;


/*
*********************************************************************************************************
*                                    NETWORK TRANSACTION DATA TYPE
*********************************************************************************************************
*/

typedef  CPU_INT08U  NET_TRANSACTION;


/*
*********************************************************************************************************
*                          NETWORK MAXIMUM TRANSMISSION UNIT (MTU) DATA TYPE
*
* Note(s) : (1) NET_MTU_MIN_VAL & NET_MTU_MAX_VAL  SHOULD be #define'd based on 'NET_MTU' data type declared.
*********************************************************************************************************
*/

typedef  CPU_INT16U  NET_MTU;
                                                                /* See Note #1.                                         */
#define  NET_MTU_MIN_VAL                DEF_INT_16U_MIN_VAL
#define  NET_MTU_MAX_VAL                DEF_INT_16U_MAX_VAL


/*
*********************************************************************************************************
*                                     NETWORK CHECK-SUM DATA TYPE
*********************************************************************************************************
*/

typedef  CPU_INT16U  NET_CHK_SUM;


/*
*********************************************************************************************************
*                                    NETWORK TIMESTAMP DATA TYPES
*
* Note(s) : (1) RFC #791, Section 3.1 'Options : Internet Timestamp' states that "the Timestamp is a
*               right-justified, 32-bit timestamp in milliseconds since midnight UT [Universal Time]".
*********************************************************************************************************
*/

typedef  CPU_INT32U  NET_TS;
typedef  NET_TS      NET_TS_MS;


/*
*********************************************************************************************************
*                                       NETWORK TIMER DATA TYPES
*********************************************************************************************************
*/

typedef  struct  net_tmr   NET_TMR;


/*
*********************************************************************************************************
*                                      NETWORK BUFFER DATA TYPES
*********************************************************************************************************
*/

typedef  struct  net_buf   NET_BUF;


/*
*********************************************************************************************************
*                                    NETWORK CONNECTION DATA TYPES
*********************************************************************************************************
*/

typedef  CPU_INT16S        NET_CONN_ID;

typedef  struct  net_conn  NET_CONN;


/*$PAGE*/
/*
*********************************************************************************************************
*                                     NETWORK PROTOCOL DATA TYPE
*********************************************************************************************************
*/

typedef  CPU_INT16U  NET_PROTOCOL_TYPE;


/*
*********************************************************************************************************
*                            NETWORK TRANSPORT LAYER PORT NUMBER DATA TYPE
*
* Note(s) : (1) NET_PORT_NBR_MAX  SHOULD be #define'd based on 'NET_PORT_NBR' data type declared.
*********************************************************************************************************
*/

typedef  CPU_INT16U  NET_PORT_NBR;

#define  NET_PORT_NBR_MAX               DEF_INT_16U_MAX_VAL     /* See Note #1.                                         */


/*
*********************************************************************************************************
*                        NETWORK TRANSPORT LAYER PORT NUMBER QUANTITY DATA TYPE
*********************************************************************************************************
*/

typedef  CPU_INT16U  NET_PORT_NBR_QTY;                          /* Defines max qty of port nbrs to support.             */


/*
*********************************************************************************************************
*                                NETWORK INTERFACE & DEVICE DATA TYPES
*
* Note(s) : (1) NET_IF_NBR_MIN_VAL & NET_IF_NBR_MAX_VAL  SHOULD be #define'd based on 'NET_IF_NBR'
*               data type declared.
*********************************************************************************************************
*/

typedef  CPU_INT08U  NET_IF_NBR;
                                                                /* See Note #1.                                         */
#define  NET_IF_NBR_MIN_VAL             DEF_INT_08U_MIN_VAL
#define  NET_IF_NBR_MAX_VAL             DEF_INT_08U_MAX_VAL


typedef  struct  net_if       NET_IF;
typedef  struct  net_if_api   NET_IF_API;


typedef  struct  net_dev_cfg  NET_DEV_CFG;

typedef  CPU_INT32U  NET_DEV_CFG_FLAGS;
typedef  CPU_INT08U  NET_DEV_ISR_TYPE;


/*
*********************************************************************************************************
*                                    NETWORK ARP LAYER DATA TYPES
*********************************************************************************************************
*/

typedef  struct  net_arp_cache  NET_ARP_CACHE;


/*
*********************************************************************************************************
*                                     NETWORK IP LAYER DATA TYPES
*********************************************************************************************************
*/

typedef  CPU_INT32U  NET_IP_ADDR;                               /* Defines IPv4 IP addr size.                           */


/*
*********************************************************************************************************
*                                    NETWORK ICMP LAYER DATA TYPES
*********************************************************************************************************
*/

typedef  struct  net_icmp_tx_src_quench  NET_ICMP_TX_SRC_QUENCH;


/*
*********************************************************************************************************
*                                    NETWORK IGMP LAYER DATA TYPES
*********************************************************************************************************
*/

typedef  struct  net_igmp_host_grp  NET_IGMP_HOST_GRP;


/*$PAGE*/
/*
*********************************************************************************************************
*                                    NETWORK TCP LAYER DATA TYPES
*********************************************************************************************************
*/

typedef  CPU_INT32U  NET_TCP_SEQ_NBR;
typedef  CPU_INT16U  NET_TCP_SEG_SIZE;
typedef  CPU_INT16U  NET_TCP_WIN_SIZE;

typedef  NET_TS_MS   NET_TCP_TX_RTT_MS;
typedef  NET_TS_MS   NET_TCP_TX_RTT_TS_MS;

typedef  struct  net_tcp_conn  NET_TCP_CONN;


/*
*********************************************************************************************************
*                                   NETWORK SOCKET LAYER DATA TYPES
*********************************************************************************************************
*/

typedef  struct  net_sock  NET_SOCK;

